@@ -22,8 +22,8 @@ __all__ = ["generate", "ask_user", "ablog_start"]
 ABLOG_CONF = "#!/usr/bin/env python\n"
 ABLOG_CONF += """
 
-# %(project)s build configuration file, created by
-# `ablog start` on %(now)s.
+# {project} build configuration file, created by
+# `ablog start` on {now}.
 #
 # Note that not all possible configuration values are present in this file.
 # All configuration values have a default; values that are commented out
@@ -40,11 +40,11 @@ import alabaster
 # blog_path = 'blog'
 
 # The "title" for the blog, used in active pages.  Default is ``'Blog'``.
-blog_title = u'%(project_str)s Blog'
+blog_title = "{project} Blog"
 
 # Base URL for the website, required for generating feeds.
 # e.g. blog_baseurl = "http://example.com/"
-blog_baseurl = u'%(blog_baseurl)s'
+blog_baseurl = "{blog_baseurl}"
 
 # Choose to archive only post titles. Archiving only titles can speed
 # up project building.
@@ -54,28 +54,28 @@ blog_baseurl = u'%(blog_baseurl)s'
 
 # A dictionary of author names mapping to author full display names and
 # links. Dictionary keys are what should be used in ``post`` directive
-# to refer to the author.  Default is ``{}``.
-blog_authors = {
-    '%(author_str)s': ('%(author_str)s', None),
-}
+# to refer to the author.  Default is ``{{}}``.
+blog_authors = {{
+    "{author}": ("{author}", None),
+}}
 
 
 # A dictionary of language code names mapping to full display names and
 # links of these languages. Similar to :confval:`blog_authors`, dictionary
 # keys should be used in ``post`` directive to refer to the locations.
-# Default is ``{}``.
-# blog_languages = {
+# Default is ``{{}}``.
+# blog_languages = {{
 #    'en': ('English', None),
-# }
+# }}
 
 
 # A dictionary of location names mapping to full display names and
 # links of these locations. Similar to :confval:`blog_authors`, dictionary
 # keys should be used in ``post`` directive to refer to the locations.
-# Default is ``{}``.
-# blog_locations = {
+# Default is ``{{}}``.
+# blog_locations = {{
 #    'Earth': ('The Blue Planet', 'https://en.wikipedia.org/wiki/Earth),
-# }
+# }}
 
 # -- Blog Post Related --------------------------------------------------------
 
@@ -117,14 +117,14 @@ blog_authors = {
 # a link to a archive pages generated for each tag, category, and year.
 # In addition, there are authors.html, languages.html, and locations.html
 # sidebars that link to author and location archive pages.
-html_sidebars = {
+html_sidebars = {{
     '**': [ 'about.html',
             'postcard.html', 'navigation.html',
             'recentposts.html', 'tagcloud.html',
             'categories.html',  'archives.html',
             'searchbox.html',
             ],
-    }
+    }}
 
 # -- Blog Feed Options --------------------------------------------------------
 
@@ -142,6 +142,23 @@ html_sidebars = {
 # Choose to feed only post titles, default is ``False``.
 # blog_feed_titles = False
 
+# Specify custom Jinja2 templates for feed entry elements:
+#     `title`, `summary`, or `content`
+# For example, to add an additional feed for posting to social media:
+# blog_feed_templates = {{
+#     # Use defaults, no templates
+#     "atom": {{}},
+#     # Create content text suitable posting to social media
+#     "social": {{
+#         # Format tags as hashtags and append to the content
+#         "content": "{{ title }}{{% for tag in post.tags %}}"
+#         " #{{ tag.name|trim()|replace(' ', '') }}"
+#         "{{% endfor %}}",
+#     }},
+# }}
+# Default: Create one `atom.xml` feed without any templates
+# blog_feed_templates = {{"atom": {{}} }}
+
 # Specify number of recent posts to include in feeds, default is ``None``
 # for all posts.
 # blog_feed_length = None
@@ -194,37 +211,37 @@ extensions = [
 ]
 
 # Add any paths that contain templates here, relative to this directory.
-templates_path = ['%(dot)stemplates', ablog.get_html_templates_path()]
+templates_path = ["{dot}templates", ablog.get_html_templates_path()]
 
 # The suffix(es) of source filenames.
-source_suffix = '%(suffix)s'
+source_suffix = "{suffix}"
 
 # The encoding of source files.
 # source_encoding = 'utf-8-sig'
 
 # The master toctree document.
-master_doc = '%(master_str)s'
+master_doc = "{master}"
 
 # General information about the project.
-project = u'%(project_str)s'
-copyright = u'%(copyright_str)s'
-author = u'%(author_str)s'
+project = "{project}"
+copyright = "{copyright}"
+author = "{author}"
 
 # The version info for the project you're documenting, acts as replacement for
 # |version| and |release|, also used in various other places throughout the
 # built documents.
 #
 # The short X.Y version.
-version = '%(version_str)s'
+version = "{version}"
 # The full version, including alpha/beta/rc tags.
-release = '%(release_str)s'
+release = "{release}"
 
 # The language for content autogenerated by Sphinx. Refer to documentation
 # for a list of supported languages.
 #
 # This is also used if you do content translation via gettext catalogs.
 # Usually you set "language" from the command line for these cases.
-language = %(language)r
+language = "{language}"
 
 # There are two options for replacing |today|: either, you set today to some
 # non-false value, then it is used:
@@ -234,7 +251,7 @@ language = %(language)r
 
 # List of patterns, relative to source directory, that match files and
 # directories to ignore when looking for source files.
-exclude_patterns = [%(exclude_patterns)s]
+exclude_patterns = ["{exclude_patterns}"]
 
 # The reST default role (used for this markup: `text`) to use for all
 # documents.
@@ -261,7 +278,7 @@ pygments_style = 'sphinx'
 # keep_warnings = False
 
 # If true, `todo` and `todoList` produce output, else they produce nothing.
-todo_include_todos = %(ext_todo)s
+todo_include_todos = "{ext_todo:}"
 
 
 # -- Options for HTML output ----------------------------------------------
@@ -273,9 +290,9 @@ html_theme = 'alabaster'
 # Theme options are theme-specific and customize the look and feel of a theme
 # further.  For a list of options available for each theme, see the
 # documentation.
-html_theme_options = {
+html_theme_options = {{
     'github_button': False,
-}
+}}
 
 # Add any paths that contain custom themes here, relative to this directory.
 html_theme_path = [alabaster.get_path()]
@@ -299,7 +316,7 @@ html_theme_path = [alabaster.get_path()]
 # Add any paths that contain custom static files (such as style sheets) here,
 # relative to this directory. They are copied after the builtin static files,
 # so a file named "default.css" will overwrite the builtin "default.css".
-html_static_path = ['%(dot)sstatic']
+html_static_path = ["{dot}static"]
 
 # Add any extra paths that contain custom files (such as robots.txt or
 # .htaccess) here, relative to this directory. These files are copied
@@ -316,7 +333,7 @@ html_static_path = ['%(dot)sstatic']
 
 # Additional templates that should be rendered to pages, maps page names to
 # template names.
-# html_additional_pages = {}
+# html_additional_pages = {{}}
 
 # If false, no module index is generated.
 # html_domain_indices = True
@@ -352,25 +369,25 @@ html_static_path = ['%(dot)sstatic']
 
 # A dictionary with options for the search language support, empty by default.
 # Now only 'ja' uses this config value
-# html_search_options = {'type': 'default'}
+# html_search_options = {{'type': 'default'}}
 
 # The name of a javascript file (relative to the configuration directory) that
 # implements a search results scorer. If empty, the default will be used.
 # html_search_scorer = 'scorer.js'
 
 # Output file base name for HTML help builder.
-htmlhelp_basename = '%(project_fn)sdoc'
+htmlhelp_basename = "{project_fn}doc"
 
 
 """
 
 ABLOG_INDEX = """
-.. %(project)s index file, created by `ablog start` on %(now)s.
+.. {project} index file, created by `ablog start` on {now}.
    You can adapt this file completely to your liking, but it should at least
    contain the root `toctree` directive.
 
-Welcome to %(author)s's Blog!
-===========%(project_underline)s=================
+Welcome to {author}'s Blog!
+==========={project_underline}=================
 
 Hello World! Find more about me here: :ref:`about`
 
@@ -398,7 +415,7 @@ Here is a list of most recent posts:
 ABLOG_ABOUT = """
 .. _about:
 
-About %(author)s
+About {author}
 ============================
 
 The world wants to know more about you.
@@ -406,11 +423,11 @@ The world wants to know more about you.
 """
 
 ABLOG_POST = """
-.. %(project)s post example, created by `ablog start` on %(post_date)s.
+.. {project} post example, created by `ablog start` on {post_date}.
 
-.. post:: %(post_date)s
+.. post:: {post_date}
    :tags: atag
-   :author: %(author_str)s
+   :author: {author}
 
 First Post
 ==========
@@ -424,7 +441,6 @@ in :ref:`first-post`. Find out more at `Cross-Referencing Blog Pages
 <https://ablog.readthedocs.org/manual/cross-referencing-blog-pages/>`__.
 """
 
-
 CONF_DEFAULTS = {
     "sep": False,
     "dot": "_",
@@ -441,9 +457,9 @@ CONF_DEFAULTS = {
 def generate(d, overwrite=True, silent=False):
     """
     Borrowed from Sphinx 1.3b3.
-    """
 
-    """Generate project based on values in *d*."""
+    Generate project based on values in *d*.
+    """
 
     texescape.init()
 
@@ -464,21 +480,6 @@ def generate(d, overwrite=True, silent=False):
         str(d["project"] + " Documentation").translate(str(d["project"] + " Documentation"))
     )
 
-    # escape backslashes and single quotes in strings that are put into
-    # a Python string literal
-    for key in (
-        "project",
-        "project_doc",
-        "project_doc_texescaped",
-        "author",
-        "author_texescaped",
-        "copyright",
-        "version",
-        "release",
-        "master",
-    ):
-        d[key + "_str"] = d[key].replace("\\", "\\\\").replace("'", "\\'")
-
     if not path.isdir(d["path"]):
         ensuredir(d["path"])
 
@@ -499,27 +500,27 @@ def generate(d, overwrite=True, silent=False):
 
     def write_file(fpath, content, newline=None):
         if overwrite or not path.isfile(fpath):
-            print("Creating file %s." % fpath)
+            print(f"Creating file {fpath}.")
             f = open(fpath, "wt", encoding="utf-8", newline=newline)
             try:
                 f.write(content)
             finally:
                 f.close()
         else:
-            print("File %s already exists, skipping." % fpath)
+            print(f"File {fpath} already exists, skipping.")
 
-    conf_text = ABLOG_CONF % d
+    conf_text = ABLOG_CONF.format(**d)
     write_file(path.join(srcdir, "conf.py"), conf_text)
 
     masterfile = path.join(srcdir, d["master"] + d["suffix"])
-    write_file(masterfile, ABLOG_INDEX % d)
+    write_file(masterfile, ABLOG_INDEX.format(**d))
 
     about = path.join(srcdir, "about" + d["suffix"])
-    write_file(about, ABLOG_ABOUT % d)
+    write_file(about, ABLOG_ABOUT.format(**d))
 
     d["post_date"] = datetime.datetime.today().strftime("%b %d, %Y")
     firstpost = path.join(srcdir, "first-post" + d["suffix"])
-    write_file(firstpost, ABLOG_POST % d)
+    write_file(firstpost, ABLOG_POST.format(**d))
 
     if silent:
         return
@@ -544,7 +545,7 @@ def ask_user(d):
 
     d.update(CONF_DEFAULTS)
 
-    print(bold("Welcome to the ABlog %s quick start utility.") % __version__)
+    print(bold(f"Welcome to the ABlog {__version__} quick start utility."))
     print("")
     print(
         w(
@@ -555,7 +556,7 @@ def ask_user(d):
 
     print("")
     if "path" in d:
-        print(bold("Selected root path: %s" % d["path"]))
+        print(bold(f"Selected root path: {d['path']}"))
     else:
         print("Enter the root path for your blog project (path has to exist).")
         d["path"] = do_prompt("Root path for your project (path has to exist)", ".", is_path)
@@ -603,8 +604,8 @@ def ask_user(d):
         print(
             bold(
                 w(
-                    "Error: the master file %s has already been found in the "
-                    "selected root path." % (d["master"] + d["suffix"])
+                    f"Error: the master file {d['master'] + d['suffix']} has already been found in the "
+                    "selected root path."
                 )
             )
         )
